@@ -245,14 +245,14 @@ class ModelVersionManagerClient:
         model_version_id: Optional[str] = None,
         model_id: Optional[str] = None,
         model_version_name: Optional[str] = None,
-    ) -> PromoteModelVersionToBuildResponse:
+    ) -> str:
         """
         Promote a model version to build.
         :param build_config: The build configuration for the promotion (required)
         :param model_version_id: Model version ID (alternative to model_id + model_version_name)
         :param model_id: Model ID (required if model_version_id is not provided)
         :param model_version_name: Model version name (required if model_version_id is not provided)
-        :return PromoteModelVersionToBuildResponse containing the build ID
+        :return The build ID of the promoted model version
         :raises FrogmlException: If the promotion fails or parameters are invalid
         """
         logger.info("Promote model version to build %s", build_config)
@@ -287,4 +287,4 @@ class ModelVersionManagerClient:
         )
 
         logger.info("promote_response = %s", promote_response)
-        return promote_response
+        return promote_response.build_id
