@@ -41,6 +41,7 @@ class BaseModelVersionManager(ABC, metaclass=SingletonABCMeta):
         metrics: Optional[Dict[str, Any]] = None,
         predict_file: Optional[str] = None,
         model_path: Optional[str] = None,
+        register_in_jml: bool = True,
     ):
         """
         Log model to a repository in Artifactory.
@@ -55,6 +56,7 @@ class BaseModelVersionManager(ABC, metaclass=SingletonABCMeta):
         :param metrics: Model metrics
         :param predict_file: Path to the predict file
         :param model_path: Path to the model file (for file-based models)
+        :param register_in_jml: Whether to register the model as a registered model to JML.
         :return: None
         """
         self._logger.debug("About to import and define framework version")
@@ -75,6 +77,7 @@ class BaseModelVersionManager(ABC, metaclass=SingletonABCMeta):
                 model_path=model_path,
                 target_dir=target_dir,
                 framework_version=framework_version,
+                register_in_jml=register_in_jml,
             )
             self._logger.info(
                 "Logging model %s to %s",
@@ -142,6 +145,7 @@ class BaseModelVersionManager(ABC, metaclass=SingletonABCMeta):
         model_path: Optional[str],
         target_dir: str,
         framework_version: str,
+        register_in_jml: bool = True,
     ) -> ModelLogConfig:
         """Build and return a ModelLogConfig instance with the provided model logging parameters.
 
@@ -168,6 +172,7 @@ class BaseModelVersionManager(ABC, metaclass=SingletonABCMeta):
                 metrics=metrics,
                 predict_file=predict_file,
                 model_path=model_path,
+                register_in_jml=register_in_jml,
             )
         except ValidationError as ve:
             errors: dict[str, str] = {"errors": ve.json()}
