@@ -6,6 +6,7 @@ from typing import Optional, Dict, Any, TextIO, Union
 import requests
 from requests import Response
 
+from frogml.core.clients.administration.eco_system.client import EcosystemClient
 from frogml.storage.frog_ml import FrogMLStorage
 from frogml.storage.models.serialization_metadata import SerializationMetadata
 from frogml.storage.models.frogml_model_version import FrogMLModelVersion
@@ -15,7 +16,6 @@ from typing_extensions import Self
 from frogml._proto.jfml.model_version.v1.model_version_framework_pb2 import (
     ModelVersionFramework,
 )
-from frogml.core.clients.jfrog_gateway import JfrogGatewayClient
 from frogml.core.clients.model_version_manager import ModelVersionManagerClient
 from frogml.core.exceptions import FrogmlException
 from frogml.sdk.model_version.constants import FROGML_LOG_LEVEL_ENVAR_NAME
@@ -32,7 +32,7 @@ class JmlCustomerClient:
         Initializes the JmlCustomerClient
         """
         self.__model_version_manager_client = ModelVersionManagerClient()
-        self.__jfrog_gateway_client = JfrogGatewayClient()
+        self.__ecosystem_client = EcosystemClient()
         self.__logger = logging.getLogger(type(self).__name__)
         self.__ml_storage = FrogMLStorage()
         self.__define_client_logger()
@@ -42,7 +42,7 @@ class JmlCustomerClient:
             return
 
         console_handler = logging.StreamHandler(stream)
-        log_level: int = logging.getLevelName(
+        log_level: str = logging.getLevelName(
             os.getenv(FROGML_LOG_LEVEL_ENVAR_NAME) or logging.INFO
         )
         console_handler.setLevel(log_level)
@@ -53,10 +53,10 @@ class JmlCustomerClient:
         self.__logger.addHandler(console_handler)
         self.__logger.setLevel(log_level)
 
-    def check_if_customer_exists_in_jml(self) -> bool:
+    def is_customer_exists_in_jml(self) -> bool:
         try:
             self.__logger.debug("Checking if customer exists in JML...")
-            self.__jfrog_gateway_client.get_jfrog_tenant_info()
+            self.__ecosystem_client.get_authenticated_user_context()
             self.__logger.info("Customer exists in JML.")
 
             return True
