@@ -124,8 +124,9 @@ def _log_model(config: ModelLogConfig) -> None:
     )
 
     is_customer_exists_in_jml: bool = (
-        jml_customer_client.check_if_customer_exists_in_jml()
+        config.register_in_jml and jml_customer_client.is_customer_exists_in_jml()
     )
+
     if is_customer_exists_in_jml:
         project_key: str = jml_customer_client.get_project_key(config.repository)
         jml_customer_client.validate_model_version(
