@@ -280,6 +280,12 @@ class ArtifactoryApi:
             url=join_url(self.uri, "/api/security/encryptedPassword")
         )
 
+    def get_repository_configuration(self: Self, repository_key: str) -> Response:
+        url: str = modify_url(
+            self.uri, f"artifactory/api/v2/repositories/{repository_key}"
+        )
+        return self.http_client.get(url=url)
+
     def generate_access_token(self: Self) -> Response:
         """
         Generates an access token for authenticating with the JFrog Platform.
